# PyPlateX
A scalable and versatile ANPR package leveraging YOLO for detection and multiple OCR options to accurately recognize license plates.

### NOTE
Still cooking in the kitchen—don’t worry, we’ll let you know when it’s done and ready to serve! 🍳